tests.models.pipeline package — django_analyses 0.0.3 documentation

# tests.models.pipeline package

## Submodules

## tests.models.pipeline.test_node module

class `tests.models.pipeline.test_node.` `NodeTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Node` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  classmethod `setUpTestData`()

    Load initial data for the TestCase.

  `test_check_configuration_sameness_for_default_value_returns_true`()
  `test_check_configuration_sameness_for_non_configuration_returns_true`()
  `test_check_configuration_sameness_for_non_default_when_key_not_configured_returns_false`()
  `test_check_configuration_sameness_for_not_same_configuration_returns_false`()
  `test_check_configuration_sameness_for_same_configuration_returns_true`()
  `test_check_run_configuration_sameness_for_not_same_configuration_returns_false`()
  `test_check_run_configuration_sameness_for_same_configuration_returns_true`()
  `test_get_full_configuration_with_defaults_and_node_configuration`()
  `test_get_full_configuration_with_defaults_and_node_configuration_and_inputs`()
  `test_get_full_configuration_with_defaults_only`()
  `test_get_required_nodes_with_a_pipe`()
  `test_get_required_nodes_with_no_pipes`()
  `test_get_requiring_nodes_with_a_pipe`()
  `test_get_requiring_nodes_with_no_pipes`()
  `test_get_run_set`()
  `test_node_validation_with_invalid_configuration_keys_raises_validation_error`()
  `test_node_validation_with_no_configuration_returns_none`()
  `test_node_validation_with_valid_configuration_keys_returns_none`()
  `test_required_nodes_with_no_required_returns_none`()
  `test_required_nodes_with_required`()
  `test_requiring_nodes_with_no_required_returns_none`()
  `test_requiring_nodes_with_required`()
  `test_run_set`()

    Tests the `run_set` property return the expected `QuerySet`.

  `test_run_with_no_user`()
  `test_run_with_user`()
  `test_string`()

## tests.models.pipeline.test_pipe module

class `tests.models.pipeline.test_pipe.` `PipeTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Pipe` model.

  `setUp`()

    Adds the created instances to the tests’ contexts. For more information see unittest’s `setUp()` method.

  `test_destination_port`()
  `test_source_port`()
  `test_string`()

## tests.models.pipeline.test_pipeline module

class `tests.models.pipeline.test_pipeline.` `PipelineTestCase`(methodName='runTest')

  Bases: `django.test.testcases.TestCase`

  Tests for the `Pipeline` model.

  `setUp`()

    For more information see unittest’s `setUp()` method.

  classmethod `setUpTestData`()

    Load initial data for the TestCase.

  `test_entry_nodes`()
  `test_get_entry_nodes`()
  `test_get_node_set`()
  `test_node_set`()
  `test_string`()

## Module contents